#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-BN7QzkHo1JpBgIH7MEm5Bu
key:                  hackage-db-2.1.3-BN7QzkHo1JpBgIH7MEm5Bu
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  2bdbd0399ee820994ce50bcc1d5f69d6
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-BN7QzkHo1JpBgIH7MEm5Bu
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-I4TBg1DJhLsFbcwgkuafNJ base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    tar-0.5.1.1-IJAjAM7qgxpFPDj1wF26Ge time-1.12.2
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

